==> scute-1.0.0.tar.bz2: scute-1.0.0/src/settings.h <==
/* settings.h - Settings for Scute's Cryptoki implementation.
   Copyright (C) 2006 g10 Code GmbH

   This file is part of Scute[1].

   [1] Derived from the RSA Security Inc. PKCS #11 Cryptographic Token
   Interface (Cryptoki).
 
   Scute is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   Scute is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Scute; if not, write to the Free Software Foundation,
   Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

   In addition, as a special exception, g10 Code GmbH gives permission
   to link this library: with the Mozilla Foundation's code for
   Mozilla (or with modified versions of it that use the same license
   as the "Mozilla" code), and distribute the linked executables.  You
   must obey the GNU General Public License in all respects for all of
   the code used other than "Mozilla".  If you modify this file, you
   may extend this exception to your version of the file, but you are
   not obligated to do so.  If you do not wish to do so, delete this
   exception statement from your version.  */

#ifndef SETTINGS_H
#define SETTINGS_H	1

/* Define this to 1 if threads are required for the implementation of
   the library.  */
#define NEED_TO_CREATE_THREADS 0

/* The manufacturer ID in UTF-8.  Only up to 32 bytes are used.  */
#define MANUFACTURER_ID	"g10 Code GmbH"

#define LIBRARY_DESCRIPTION	"Cryptoki for SCDaemon"

/* The version number of this library.  Defined by config.h.  */
#if (! defined VERSION_MAJOR) || (! defined VERSION_MINOR)
#error Define VERSION_MAJOR and VERSION_MINOR in config.h.
#endif

/* FIXME: The following should be queried from SCD, really.  */
#define SLOT_DESCRIPTION "GnuPG Smart Card Daemon"
#define SLOT_MANUFACTURER_ID "g10 Code GmbH"
#define SLOT_HARDWARE_VERSION_MAJOR 0
#define SLOT_HARDWARE_VERSION_MINOR 0
#define SLOT_FIRMWARE_VERSION_MAJOR 0
#define SLOT_FIRMWARE_VERSION_MINOR 0

#endif	/* !SETTINGS_H */

==> scute-1.2.0.tar.bz2: scute-1.2.0/src/settings.h <==
/* settings.h - Settings for Scute's Cryptoki implementation.
   Copyright (C) 2006 g10 Code GmbH

   This file is part of Scute.
 
   Scute is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   Scute is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Scute; if not, write to the Free Software Foundation,
   Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

   In addition, as a special exception, g10 Code GmbH gives permission
   to link this library: with the Mozilla Foundation's code for
   Mozilla (or with modified versions of it that use the same license
   as the "Mozilla" code), and distribute the linked executables.  You
   must obey the GNU General Public License in all respects for all of
   the code used other than "Mozilla".  If you modify this file, you
   may extend this exception to your version of the file, but you are
   not obligated to do so.  If you do not wish to do so, delete this
   exception statement from your version.  */

#ifndef SETTINGS_H
#define SETTINGS_H	1

/* Define this to 1 if threads are required for the implementation of
   the library.  */
#define NEED_TO_CREATE_THREADS 0

/* The manufacturer ID in UTF-8.  Only up to 32 bytes are used.  */
#define MANUFACTURER_ID	"g10 Code GmbH"

#define LIBRARY_DESCRIPTION	"Cryptoki for SCDaemon"

/* The version number of this library.  Defined by config.h.  */
#if (! defined VERSION_MAJOR) || (! defined VERSION_MINOR)
#error Define VERSION_MAJOR and VERSION_MINOR in config.h.
#endif

/* FIXME: The following should be queried from SCD, really.  */
#define SLOT_DESCRIPTION "GnuPG Smart Card Daemon"
#define SLOT_MANUFACTURER_ID "g10 Code GmbH"
#define SLOT_HARDWARE_VERSION_MAJOR 0
#define SLOT_HARDWARE_VERSION_MINOR 0
#define SLOT_FIRMWARE_VERSION_MAJOR 0
#define SLOT_FIRMWARE_VERSION_MINOR 0

#endif	/* !SETTINGS_H */
